@@ -57,6 +57,10 @@ mod asum;
 pub use asum::sasum;
 pub use asum::dasum;
 
+mod axpy;
+pub use axpy::saxpy;
+pub use axpy::daxpy;
+
 mod dot;
 pub use dot::sdot;
 pub use dot::ddot;
@@ -69,10 +73,9 @@ mod scal;
 pub use scal::sscal;
 pub use scal::dscal;
 
-mod axpy;
-pub use axpy::saxpy;
-pub use axpy::daxpy;
-
+mod swap;
+pub use swap::sswap;
+pub use swap::dswap;
 
 
 #[cfg(test)]
